aboutsummaryrefslogtreecommitdiff
path: root/sys/alpha/include/proc.h
diff options
context:
space:
mode:
authorDoug Rabson <dfr@FreeBSD.org>1998-11-15 18:25:17 +0000
committerDoug Rabson <dfr@FreeBSD.org>1998-11-15 18:25:17 +0000
commit08b6a4cbee427b68518039a35579f86d2e646bb9 (patch)
treefd54512c9c731113c4672699fae373a27076692f /sys/alpha/include/proc.h
parent128d4f3960c20175f0c33050be82862db5378087 (diff)
Notes
Diffstat (limited to 'sys/alpha/include/proc.h')
-rw-r--r--sys/alpha/include/proc.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/sys/alpha/include/proc.h b/sys/alpha/include/proc.h
index 6a1af705706e3..de24336006604 100644
--- a/sys/alpha/include/proc.h
+++ b/sys/alpha/include/proc.h
@@ -1,4 +1,4 @@
-/* $Id: proc.h,v 1.2 1998/06/10 10:55:17 dfr Exp $ */
+/* $Id: proc.h,v 1.3 1998/07/15 20:16:27 dfr Exp $ */
/* From: NetBSD: proc.h,v 1.3 1997/04/06 08:47:36 cgd Exp */
/*
@@ -38,12 +38,14 @@ struct mdbpt {
};
struct mdproc {
- u_long md_flags;
+ u_long md_flags;
struct trapframe *md_tf; /* trap/syscall registers */
- struct pcb *md_pcbpaddr; /* phys addr of the pcb */
- struct mdbpt md_sstep[2]; /* two single step breakpoints */
+ struct pcb *md_pcbpaddr; /* phys addr of the pcb */
+ struct mdbpt md_sstep[2]; /* two single step breakpoints */
+ u_int64_t md_hae; /* user HAE register value */
};
#define MDP_FPUSED 0x0001 /* Process used the FPU */
#define MDP_STEP1 0x0002 /* Single step normal instruction */
#define MDP_STEP2 0x0004 /* Single step branch instruction */
+#define MDP_HAEUSED 0x0008 /* Process used the HAE */